@@ -1,14 +1,13 @@
-#!/usr/bin/python
 # -*- coding: utf-8 -*-
 #
-# urlwatch is a minimalistic URL watcher written in Python
-#
-# Copyright (c) 2008-2014 Thomas Perl <thp.io/about>
+# This file is part of urlwatch (https://thp.io/2008/urlwatch/).
+# Copyright (c) 2008-2015 Thomas Perl <thp.io/about>
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions
 # are met:
+#
 # 1. Redistributions of source code must retain the above copyright
 #    notice, this list of conditions and the following disclaimer.
 # 2. Redistributions in binary form must reproduce the above copyright
@@ -27,7 +26,6 @@
 # THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 # (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 # THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-#
 
 try:
     # Available in Python 2.5 and above and preferred if available
@@ -42,10 +40,22 @@ except ImportError:
 import subprocess
 import email.utils
 import urllib2
+import urlparse
 import os
 import stat
 import sys
 import re
+import zlib
+
+def get_current_user():
+    try:
+        return os.getlogin()
+    except OSError:
+        # If there is no controlling terminal, because urlwatch is launched by
+        # cron, or by a systemd.service for example, os.getlogin() fails with:
+        # OSError: [Errno 25] Inappropriate ioctl for device
+        import pwd
+        return pwd.getpwuid(os.getuid()).pw_name
 
 class JobBase(object):
     def __init__(self, location):
@@ -123,12 +133,27 @@ class UrlJob(JobBase):
         else:
             post_data = None
 
+        parts = urlparse.urlparse(self.location)
+        if parts.username or parts.password:
+            self.location = urlparse.urlunparse((parts.scheme, parts.hostname, parts.path,
+                                                 parts.params, parts.query, parts.fragment))
+            log.info('Using HTTP basic authentication for %s', self.location)
+            headers['Authorization'] = 'Basic %s' % (':'.join((parts.username,
+                                                               parts.password)).encode('base64').strip())
+
         request = urllib2.Request(self.location, post_data, headers)
         response = urllib2.urlopen(request)
         headers = response.info()
         content = response.read()
         encoding = 'utf-8'
 
+        # Handle HTTP compression
+        compression_type = headers.get('Content-Encoding')
+        if compression_type == 'gzip':
+            content = zlib.decompress(content, zlib.MAX_WBITS|32)
+        elif compression_type == 'deflate':
+            content = zlib.decompress(content, -zlib.MAX_WBITS)
+
         # Determine content type via HTTP headers
         content_type = headers.get('Content-type', '')
         content_type_match = self.CHARSET_RE.match(content_type)
@@ -162,7 +187,7 @@ def parse_urls_txt(urls_txt):
         shelljob_errors.append('%s is group/world-writable' % dirname)
         allow_shelljobs = False
     if dir_st.st_uid != current_uid:
-        shelljob_errors.append('%s not owned by %s' % (dirname, os.getlogin()))
+        shelljob_errors.append('%s not owned by %s' % (dirname, get_current_user()))
         allow_shelljobs = False
 
     file_st = os.stat(urls_txt)
@@ -170,7 +195,7 @@ def parse_urls_txt(urls_txt):
         shelljob_errors.append('%s is group/world-writable' % urls_txt)
         allow_shelljobs = False
     if file_st.st_uid != current_uid:
-        shelljob_errors.append('%s not owned by %s' % (urls_txt, os.getlogin()))
+        shelljob_errors.append('%s not owned by %s' % (urls_txt, get_current_user()))
         allow_shelljobs = False
 
     for line in open(urls_txt).read().splitlines():
